@@ -11,13 +11,11 @@ use strict;
 use warnings;
 
 package Timer::Simple;
-# git description: v1.004-5-gb873a31
-$Timer::Simple::VERSION = '1.005';
-BEGIN {
-  $Timer::Simple::AUTHORITY = 'cpan:RWSTAUNER';
-}
-# ABSTRACT: Small, simple timer (stopwatch) object
+# git description: v1.005-3-gd10352e
 
+our $AUTHORITY = 'cpan:RWSTAUNER';
+# ABSTRACT: Small, simple timer (stopwatch) object
+$Timer::Simple::VERSION = '1.006';
 use Carp qw(croak carp); # core
 use overload # core
   '""' => \&string,
@@ -196,9 +194,9 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Randy Stauner ACKNOWLEDGEMENTS Tomohiro Hosaka <bokutin@bokut.in> hms cpan
-testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto
-metadata placeholders metacpan
+=for :stopwords Randy Stauner ACKNOWLEDGEMENTS (@pc-office) Hosaka Tomohiro perlancar hms
+cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc
+mailto metadata placeholders metacpan
 
 =head1 NAME
 
@@ -206,7 +204,7 @@ Timer::Simple - Small, simple timer (stopwatch) object
 
 =head1 VERSION
 
-version 1.005
+version 1.006
 
 =head1 SYNOPSIS
 
@@ -380,6 +378,12 @@ using L<Time::HiRes/gettimeofday> or L<time|perlfunc/time>.
 
 =head1 FUNCTIONS
 
+The following functions should not be necessary in most circumstances
+but are provided for convenience to facilitate additional functionality.
+
+They are not available for export (to avoid L<Exporter> overhead).
+See L<Sub::Import> if you really want to import these methods.
+
 =head2 HIRES
 
 Indicates whether L<Time::HiRes> is available.
@@ -413,14 +417,6 @@ the value will be passed through L</separate_hms> first.
 Separate seconds into hours, minutes, and seconds.
 Returns a list.
 
-=head1 FUNCTIONS
-
-The following functions should not be necessary in most circumstances
-but are provided for convenience to facilitate additional functionality.
-
-They are not available for export (to avoid L<Exporter> overhead).
-See L<Sub::Import> if you really want to import these methods.
-
 =for test_synopsis my ( $timer1, $timer2 );
 no strict 'subs';
 
@@ -441,7 +437,7 @@ L<Time::Progress> - Doesn't support L<Time::HiRes>
 
 =item *
 
-L<Time::StopWatch> - tied scalar
+L<Time::Stopwatch> - tied scalar
 
 =item *
 
@@ -477,7 +473,7 @@ L<http://metacpan.org/release/Timer-Simple>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-timer-simple at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Timer-Simple>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Timer-Simple>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -491,10 +487,22 @@ L<https://github.com/rwstauner/Timer-Simple>
 
 Randy Stauner <rwstauner@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
+
+=for stopwords Tomohiro Hosaka perlancar (@pc-office)
+
+=over 4
+
+=item *
 
 Tomohiro Hosaka <bokutin@bokut.in>
 
+=item *
+
+perlancar (@pc-office) <perlancar@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 by Randy Stauner.
